==> haskell-vty-crossplatform-0.4.0.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-crossplatform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-crossplatform
version:              0.4.0.0
visibility:           public
id:                   vty-crossplatform-0.4.0.0-2SXRfVwh841GxaOQJXMTTp
key:                  vty-crossplatform-0.4.0.0-2SXRfVwh841GxaOQJXMTTp
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Cross-platform support for Vty
description:
    This package provides a generic interface for multiple
    Vty platforms in one package so you don'\''t have to
    conditionally depend on them in your cabal file.

category:             Graphics
abi:                  8728503172846c83dbda06f786b2afc1
exposed:              True
exposed-modules:
    Graphics.Vty.CrossPlatform Graphics.Vty.CrossPlatform.Testing

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-crossplatform
hs-libraries:         HSvty-crossplatform-0.4.0.0-2SXRfVwh841GxaOQJXMTTp
depends:
    base-4.17.2.1 vty-6.1-CWgCtA0fP5b6tAqdGxpi0I
    vty-unix-0.2.0.0-JXhys9BgbLqJpHPTU31ei2

haddock-interfaces:
    /usr/share/doc/haskell-vty-crossplatform/html/vty-crossplatform.haddock

haddock-html:         /usr/share/doc/haskell-vty-crossplatform/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-crossplatform-0.4.0.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-crossplatform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-crossplatform
version:              0.4.0.0
visibility:           public
id:                   vty-crossplatform-0.4.0.0-2ZWccgfGNzJ7bhFmPiK7fw
key:                  vty-crossplatform-0.4.0.0-2ZWccgfGNzJ7bhFmPiK7fw
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Cross-platform support for Vty
description:
    This package provides a generic interface for multiple
    Vty platforms in one package so you don'\''t have to
    conditionally depend on them in your cabal file.

category:             Graphics
abi:                  b1e680e15a166abf9e25be767d413e9a
exposed:              True
exposed-modules:
    Graphics.Vty.CrossPlatform Graphics.Vty.CrossPlatform.Testing

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-crossplatform
hs-libraries:         HSvty-crossplatform-0.4.0.0-2ZWccgfGNzJ7bhFmPiK7fw
depends:
    base-4.17.2.1 vty-6.1-KJIgXUqHdUsJo19EMU1KL4
    vty-unix-0.2.0.0-6Q37XqaMPXLAKDh9pzlfmF

haddock-interfaces:
    /usr/share/doc/haskell-vty-crossplatform/html/vty-crossplatform.haddock

haddock-html:         /usr/share/doc/haskell-vty-crossplatform/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
